@@ -572,7 +572,7 @@ RDMResponse *ResponderHelper::RecordSensor(
     return NackWithReason(request, NR_FORMAT_ERROR);
   }
 
-  if (sensor_number == ALL_SENSORS) {
+  if ((sensor_number == ALL_SENSORS) && (sensor_list.size() > 0)) {
     Sensors::const_iterator iter = sensor_list.begin();
     for (; iter != sensor_list.end(); ++iter) {
       (*iter)->Record();
@@ -615,7 +615,7 @@ RDMResponse *ResponderHelper::GetRealTimeClock(
   tm_now = *localtime(&now);  // NOLINT(runtime/threadsafe_fn)
 #else
   localtime_r(&now, &tm_now);
-#endif
+#endif  // _WIN32
 
   struct clock_s clock;
   clock.year = HostToNetwork(static_cast<uint16_t>(1900 + tm_now.tm_year));
