@@ -106,10 +106,10 @@ class DiscoveryTargetInterface {
 
 
 /**
- * @brief An asyncronous RDM Discovery algorithm.
+ * @brief An asynchronous RDM Discovery algorithm.
  *
  * This implements the binary search algorithm from the E1.20 standard. The
- * implementation is asyncronous and relies on callbacks to indicate when each
+ * implementation is asynchronous and relies on callbacks to indicate when each
  * step completes.
  *
  * To use the DiscoveryAgent, one should write a class that implements the
@@ -172,10 +172,10 @@ class DiscoveryAgent {
    * @brief Represents a range of UIDs (a branch of the UID tree)
    */
   struct UIDRange {
-    UIDRange(const UID &lower, const UID &upper, UIDRange *parent)
-        : lower(lower),
-          upper(upper),
-          parent(parent),
+    UIDRange(const UID &_lower, const UID &_upper, UIDRange *_parent)
+        : lower(_lower),
+          upper(_upper),
+          parent(_parent),
           attempt(0),
           failures(0),
           uids_discovered(0),
